@@ -1,11 +1,13 @@
-#!/usr/bin/env python3
-"""
-SUISA Sendemeldung bugs SUISA with email once per month.
+"""SUISA Sendemeldung bugs SUISA with email once per month.
 
 Fetches data on our playout history and formats them in a CSV file format
-containing the data (like Track, Title and ISRC) requested by SUISA. Also takes care of sending
-the report to SUISA via email for hands-off operations.
+containing the data (like Track, Title and ISRC) requested by SUISA. Also
+takes care of sending the report to SUISA via email for hands-off operations.
 """
+
+from __future__ import annotations
+
+import sys
 from csv import reader, writer
 from datetime import date, datetime, timedelta
 from email.encoders import encode_base64
@@ -14,22 +16,29 @@ from email.mime.multipart import MIMEMultipart
 from email.mime.text import MIMEText
 from email.utils import formatdate
 from io import BytesIO, StringIO
-from os.path import basename, expanduser
+from pathlib import Path
 from smtplib import SMTP
 from string import Template
+from typing import TYPE_CHECKING, Any
 
 import cridlib
 import pytz
 from babel.dates import format_date
-from configargparse import ArgumentParser
+from configargparse import ArgumentParser  # type: ignore[import-untyped]
 from dateutil.relativedelta import relativedelta
 from iso3901 import ISRC
 from openpyxl import Workbook
+from openpyxl.cell.cell import Cell, MergedCell
 from openpyxl.styles import Border, Font, PatternFill, Side
 from tqdm import tqdm
 
 from .acrclient import ACRClient
 
+if TYPE_CHECKING:  # pragma: no cover
+    from argparse import Namespace as ArgparseNamespace
+
+    from openpyxl.worksheet.worksheet import Worksheet
+
 _EMAIL_TEMPLATE = """
 Hallo SUISA
 
@@ -76,38 +85,49 @@ $station_name
 
 --
 $email_footer
-"""
+"""  # noqa: E501
+
+_ACRTOKEN_MAXLEN = 32
 
 
-def validate_arguments(parser, args):
+def validate_arguments(parser: ArgumentParser, args: ArgparseNamespace) -> None:
     """Validate the arguments provided to the script.
 
     After this function we are sure that there are no conflicts in the arguments.
 
     Arguments:
+    ---------
         parser: the ArgumentParser to use for throwing errors
         args: the arguments to validate
+
     """
     msgs = []
     # check length of bearer_token
-    if not len(args.bearer_token) >= 32:
+    if not len(args.bearer_token) >= _ACRTOKEN_MAXLEN:
         msgs.append(
             "".join(
                 (
-                    "wrong format on bearer_token, ",
-                    f"expected larger than 32 characters but got {len(args.bearer_token)}",
-                )
-            )
+                    "wrong format on bearer_token, "
+                    "expected larger than 32 characters "
+                    f"but got {len(args.bearer_token)}"
+                ),
+            ),
         )
     # check length of stream_id
-    if not len(args.stream_id) == 9:
+    if len(args.stream_id) not in [9, 10]:
         msgs.append(
-            f"wrong format on stream_id, expected 9 characters but got {len(args.stream_id)}"
+            (
+                "wrong format on stream_id, "
+                f"expected 9 or 10 characters but got {len(args.stream_id)}"
+            ),
         )
+    # crid mode can be local or cridlib
+    if args.crid_mode not in ["cridlib", "local"]:
+        msgs.append("wrong CRID mode, expected 'cridlib' or 'local'")
     # one output option has to be set
     if not (args.file or args.email or args.stdout):
         msgs.append(
-            "no output option has been set, specify one of --file, --email or --stdout"
+            "no output option has been set, specify one of --file, --email or --stdout",
         )
     # xlsx cannot be printed to stdout
     if args.stdout and args.filetype == "xlsx":
@@ -120,14 +140,18 @@ def validate_arguments(parser, args):
         parser.error("\n- " + "\n- ".join(msgs))
 
 
-def get_arguments(parser: ArgumentParser):  # pragma: no cover
+def get_arguments(parser: ArgumentParser, sysargs: list[str]) -> ArgparseNamespace:
     """Create :class:`ArgumentParser` with arguments.
 
     Arguments:
+    ---------
         parser: the parser to add arguments
+        sysargs: sys.arg[1:] or something else for testing
 
     Returns:
+    -------
         args: the parsed args from the parser
+
     """
     parser.add_argument(
         "--bearer-token",
@@ -160,7 +184,10 @@ def get_arguments(parser: ArgumentParser):  # pragma: no cover
         default="rabe",
     )
     parser.add_argument(
-        "--file", env_var="FILE", help="create file", action="store_true"
+        "--file",
+        env_var="FILE",
+        help="create file",
+        action="store_true",
     )
     parser.add_argument(
         "--filetype",
@@ -170,19 +197,30 @@ def get_arguments(parser: ArgumentParser):  # pragma: no cover
         default="xlsx",
     )
     parser.add_argument(
-        "--email", env_var="EMAIL", help="send an email", action="store_true"
+        "--email",
+        env_var="EMAIL",
+        help="send an email",
+        action="store_true",
     )
     parser.add_argument(
-        "--email-from", env_var="EMAIL_FROM", help="the sender of the email"
+        "--email-from",
+        env_var="EMAIL_FROM",
+        help="the sender of the email",
     )
     parser.add_argument(
-        "--email-to", env_var="EMAIL_TO", help="the recipients of the email"
+        "--email-to",
+        env_var="EMAIL_TO",
+        help="the recipients of the email",
     )
     parser.add_argument(
-        "--email-cc", env_var="EMAIL_CC", help="the cc recipients of the email"
+        "--email-cc",
+        env_var="EMAIL_CC",
+        help="the cc recipients of the email",
     )
     parser.add_argument(
-        "--email-bcc", env_var="EMAIL_BCC", help="the bcc recipients of the email"
+        "--email-bcc",
+        env_var="EMAIL_BCC",
+        help="the bcc recipients of the email",
     )
     parser.add_argument(
         "--email-server",
@@ -195,19 +233,28 @@ def get_arguments(parser: ArgumentParser):  # pragma: no cover
         help="the username to logon to the smtp server (default: email_from)",
     )
     parser.add_argument(
-        "--email-pass", env_var="EMAIL_PASS", help="the password for the smtp server"
+        "--email-pass",
+        env_var="EMAIL_PASS",
+        help="the password for the smtp server",
     )
     parser.add_argument(
         "--email-subject",
         env_var="EMAIL_SUBJECT",
-        help="The subject of the email, placeholders are $station_name, $year and $month",
+        help="""
+        Template for subject of the email.
+
+        Placeholders are $station_name, $year and $month.
+        """,
         default="SUISA Sendemeldung von $station_name für $year-$month",
     )
     parser.add_argument(
         "--email-text",
         env_var="EMAIL_TEXT",
         help="""
-        A template for the Email text, placeholders are $station_name, $month, $year, $previous_year, $responsible_email, and $email_footer.
+        Template for email text.
+
+        Placeholders are $station_name, $month, $year, $previous_year,
+        $responsible_email, and $email_footer.
         """,
         default=_EMAIL_TEMPLATE,
     )
@@ -256,30 +303,46 @@ def get_arguments(parser: ArgumentParser):  # pragma: no cover
         "--filename",
         env_var="FILENAME",
         help="""
-        file to write to (default: <station_name_short>_<year>_<month>.csv when reporting last month, <station_name_short>_<start_date>.csv else)
+        Output filename.
+
+        Default:
+        - <station_name_short>_<year>_<month>.csv when reporting last month
+        - <station_name_short>_<start_date>.csv else
         """,
     )
     parser.add_argument(
-        "--stdout", env_var="STDOUT", help="also print to stdout", action="store_true"
+        "--stdout",
+        env_var="STDOUT",
+        help="also print to stdout",
+        action="store_true",
     )
-    args = parser.parse_args()
-    validate_arguments(parser, args)
-    return args
+    parser.add_argument(
+        "--crid-mode",
+        env_var="CRID_MODE",
+        help="Choose how to generate CRID identifiers (cridlib or local)",
+        default="cridlib",
+    )
+    args = parser.parse_args(sysargs)
+    validate_arguments(parser, args)  # pragma: no cover
+    return args  # pragma: no cover
 
 
-def parse_date(args):
+def parse_date(args: ArgparseNamespace) -> tuple[date, date]:
     """Parse date from args.
 
     Arguments:
+    ---------
         args: the arguments provided to the script
 
     Returns:
+    -------
         start_date: the start date of the requested interval
         end_date: the end date of the requested interval
+
     """
     # date parsing logic
     if args.last_month:
-        today = date.today()
+        today = date.today()  # noqa: DTZ011
         # get first of this month
         this_month = today.replace(day=1)
         # last day of last month = first day of this month - 1 day
@@ -287,26 +350,30 @@ def parse_date(args):
         start_date = end_date.replace(day=1)
     else:
         if args.end_date:
-            end_date = datetime.strptime(args.end_date, "%Y-%m-%d").date()
+            end_date = datetime.strptime(args.end_date, "%Y-%m-%d").date()  # noqa: DTZ007
         else:
             # if no end_date was set, default to today
-            end_date = date.today()
+            end_date = date.today()  # noqa: DTZ011
         if args.start_date:
-            start_date = datetime.strptime(args.start_date, "%Y-%m-%d").date()
+            start_date = datetime.strptime(args.start_date, "%Y-%m-%d").date()  # noqa: DTZ007
         else:
             # if no start_date was set, default to 30 days before end_date
             start_date = end_date - timedelta(days=30)
     return start_date, end_date
 
 
-def parse_filename(args, start_date):
+def parse_filename(args: ArgparseNamespace, start_date: date) -> str:
     """Parse filename from args and start_date.
 
     Arguments:
+    ---------
         args: the arguments provided to the script
+        start_date: start of reporting period
 
     Returns:
+    -------
         filename: the filename to use for the csv data
+
     """
     if args.filename:
         filename = args.filename
@@ -315,19 +382,25 @@ def parse_filename(args, start_date):
         date_part = f"{start_date.strftime('%Y')}_{start_date.strftime('%m')}"
         filename = f"{args.station_name_short}_{date_part}.{args.filetype}"
     else:
-        filename = f"{args.station_name_short}_{start_date.strftime('%Y-%m-%d')}.{args.filetype}"
+        filename = (
+            f"{args.station_name_short}_"
+            f"{start_date.strftime('%Y-%m-%d')}.{args.filetype}"
+        )
     return filename
 
 
-def check_duplicate(entry_a, entry_b):
+def check_duplicate(entry_a: Any, entry_b: Any) -> bool:  # noqa: ANN401
     """Check if two entries are duplicates by checking their acrid in all music items.
 
     Arguments:
+    ---------
         entry_a: first entry
         entry_b: second entry
 
     Returns:
+    -------
         True if the entries are duplicates, False otherwise
+
     """
     try:
         entry_a = entry_a["metadata"]["music"]
@@ -344,14 +417,17 @@ def check_duplicate(entry_a, entry_b):
     return False
 
 
-def merge_duplicates(data):
+def merge_duplicates(data: Any) -> Any:  # noqa: ANN401
     """Merge consecutive entries into one if they are duplicates.
 
     Arguments:
+    ---------
         data: The data provided by ACRClient
 
     Returns:
+    -------
         data: The processed data
+
     """
     prev = data[0]
     mark = []
@@ -371,12 +447,15 @@ def merge_duplicates(data):
     return data
 
 
-def funge_release_date(release_date: str = ""):
+def funge_release_date(release_date: str = "") -> str:
     """Make a release_date from ACR conform to what seems to be the spec."""
-
-    if len(release_date) == 10:
-        # we can make it look like what suisa has in their examples if it's the right length
-        return datetime.strptime(release_date, "%Y-%m-%d").strftime("%Y%m%d")
+    if len(release_date) == 10:  # noqa: PLR2004
+        # we can make it look like what suisa has in their examples if it's the
+        # right length
+        try:
+            return datetime.strptime(release_date, "%Y-%m-%d").strftime("%Y%m%d")  # noqa: DTZ007
+        except ValueError:
+            return ""
     # we discard other records since there is no way to convert records like a plain
     # year into dd/mm/yyyy properly without further guidance from whomever ingests
     # the data, in some cases this means we discard data that only contain a year
@@ -384,14 +463,17 @@ def funge_release_date(release_date: str = ""):
     return ""
 
 
-def get_artist(music):
+def get_artist(music: Any) -> str:  # noqa: ANN401
     """Get artist from a given dict.
 
     Arguments:
+    ---------
         music: music dict from API
 
     Returns:
+    -------
         artist: string representing the artist
+
     """
     artist = ""
     if music.get("artists") is not None:
@@ -414,7 +496,31 @@ def get_artist(music):
     return artist
 
 
-def get_isrc(music):
+def get_composer(music: Any) -> str:  # noqa: ANN401
+    """Get composer from a given dict.
+
+    Arguments:
+    ---------
+        music: music dict from API
+
+    Returns:
+    -------
+        composer: string representing the composer
+
+    """
+    # composers is usually represented as a list of strings, e.g.:
+    # 'contributors': {'composers': ['Alison Rachel Stewart', ...]}
+    # if composers is not in the expected format, we just return an empty string
+    composer = ""
+    contributors = music.get("contributors")
+    if contributors is not None:
+        composers = contributors.get("composers")
+        if composers is not None and isinstance(composers, list):
+            composer = ", ".join(composers)
+    return composer
+
+
+def get_isrc(music: Any) -> str:  # noqa: ANN401
     """Get a valid ISRC from the music record or return an empty string."""
     isrc = ""
     if music.get("external_ids", {}).get("isrc"):
@@ -439,17 +545,20 @@ def get_isrc(music):
     return isrc
 
 
-# all local vars are required, eight are already used for the csv entries
-# pylint: disable-msg=too-many-locals
-def get_csv(data, station_name=""):
+def get_csv(data: dict, args: ArgparseNamespace) -> str:
     """Create SUISA compatible csv data.
 
     Arguments:
+    ---------
         data: To data to create csv from
+        args: Parsed arguments
 
     Returns:
+    -------
         csv: The converted data
+
     """
+    station_name = args.station_name
     header = [
         "Titel",
         "Komponist",
@@ -484,7 +593,7 @@ def get_csv(data, station_name=""):
     for entry in tqdm(data, desc="preparing tracks for report"):
         metadata = entry.get("metadata")
         # parse timestamp
-        timestamp = datetime.strptime(metadata.get("timestamp_local"), ACRClient.TS_FMT)
+        timestamp = datetime.strptime(metadata.get("timestamp_local"), ACRClient.TS_FMT)  # noqa: DTZ007
 
         ts_date = timestamp.strftime("%Y%m%d")
         ts_time = timestamp.strftime("%H:%M:%S")
@@ -500,10 +609,21 @@ def get_csv(data, station_name=""):
         title = music.get("title")
 
         artist = get_artist(music)
+        composer = get_composer(music)
 
-        composer = ", ".join(music.get("contributors", {}).get("composers", ""))
-        if not composer:
-            composer = artist
+        works_composer = ", ".join(
+            [
+                c["name"]
+                for c in [
+                    item
+                    for sublist in [w["creators"] for w in music.get("works", [])]
+                    for item in sublist
+                ]
+                if c.get("role", "") in ["C", "Composer", "W", "Writer"]
+            ],
+        )
+        if works_composer and (not composer or composer == artist):
+            composer = works_composer
 
         isrc = get_isrc(music)
         label = music.get("label")
@@ -516,14 +636,21 @@ def get_csv(data, station_name=""):
         upc = music.get("external_ids", {}).get("upc", "")
         release_date = funge_release_date(music.get("release_date", ""))
 
+        local_id: str
         # cridlib only supports timezone-aware datetime values, so we convert one
         timestamp_utc = pytz.utc.localize(
-            datetime.strptime(metadata.get("timestamp_utc"), ACRClient.TS_FMT)
+            datetime.strptime(metadata.get("timestamp_utc"), ACRClient.TS_FMT),  # noqa: DTZ007
         )
         # we include the acrid in our CRID so we know about the data's provenience
         # in case any questions about the data we delivered are asked
         acrid = music.get("acrid")
-        local_id = cridlib.get(timestamp=timestamp_utc, fragment=f"acrid={acrid}")
+
+        if args.crid_mode == "cridlib":
+            local_id = str(
+                cridlib.get(timestamp=timestamp_utc, fragment=f"acrid={acrid}")
+            )
+        elif args.crid_mode == "local":
+            local_id = f"{timestamp_utc.isoformat()}#acrid={acrid}"
 
         csv_writer.writerow(
             [
@@ -552,26 +679,32 @@ def get_csv(data, station_name=""):
                 "",  # Label Code
                 upc,
                 local_id,
-            ]
+            ],
         )
     return csv.getvalue()
 
 
-def get_xlsx(data, station_name=""):
+def get_xlsx(data: Any, args: ArgparseNamespace) -> BytesIO:  # noqa: ANN401
     """Create SUISA compatible xlsx data.
 
     Arguments:
+    ---------
         data: The data to create xlsx from
+        args: Parsed arguments
 
     Returns:
+    -------
         xlsx: The converted data as BytesIO object
+
     """
-    csv = get_csv(data, station_name=station_name)
+    csv = get_csv(data, args=args)
     csv_reader = reader(StringIO(csv))
 
     xlsx = BytesIO()
-    workbook = Workbook()
-    worksheet = workbook.active
+    workbook: Workbook = Workbook()
+    if not workbook.active:  # pragma: no cover
+        raise RuntimeError
+    worksheet: Worksheet = workbook.active  # type: ignore[assignment]
 
     for row in csv_reader:
         worksheet.append(row)
@@ -600,12 +733,13 @@ def get_xlsx(data, station_name=""):
             cell.fill = fill
 
     # Try to approximate the required width by finding the longest values per column
-    dims = {}
-    for row in worksheet.rows:
-        for cell in row:
-            if cell.value:
+    dims: dict[str, int] = {}
+    calc_row: tuple[Cell | MergedCell, ...]
+    for calc_row in worksheet.rows:
+        for cell in calc_row:
+            if isinstance(cell, Cell) and cell.value:
                 dims[cell.column_letter] = max(
-                    (dims.get(cell.column_letter, 0), len(str(cell.value)))
+                    (dims.get(cell.column_letter, 0), len(str(cell.value))),
                 )
     # apply estimated width to each column
     padding = 3
@@ -616,58 +750,79 @@ def get_xlsx(data, station_name=""):
     return xlsx
 
 
-def write_csv(filename, csv):  # pragma: no cover
+def write_csv(filename: str, csv: str) -> None:  # pragma: no cover
     """Write contents of `csv` to file.
 
     Arguments:
+    ---------
         filename: The file to write to.
         csv: The data to write to `filename`.
+
     """
-    with open(filename, mode="w", encoding="utf-8") as csvfile:
+    with Path(filename).open("w", encoding="utf-8") as csvfile:
         csvfile.write(csv)
 
 
-def write_xlsx(filename, xlsx):  # pragma: no cover
+def write_xlsx(filename: str, xlsx: BytesIO) -> None:  # pragma: no cover
     """Write contents of `xlsx` to file.
 
     Arguments:
+    ---------
         filename: The file to write to.
         xlsx: The data to write to `filename`.
+
     """
-    with open(filename, mode="wb") as xlsxfile:
+    with Path(filename).open("wb") as xlsxfile:
         xlsxfile.write(xlsx.getvalue())
 
 
-def get_email_attachment(filename, filetype, data):
+def get_email_attachment(filename: str, filetype: str, data: Any) -> MIMEBase:  # noqa: ANN401
     """Create attachment based on required filetype and data.
 
     Arguments:
+    ---------
         filename: The filename of the attachment
         filetype: The filetype of the attachment
         data: The attachment data
+
     """
-    part = None
+    maintype: str
+    subtype: str
+    payload: str
     if filetype == "xlsx":
-        part = MIMEBase("application", "vnd.ms-excel")
-        part.set_payload(data.getvalue())
-        encode_base64(part)
+        maintype = "application"
+        subtype = "vnd.ms-excel"
+        payload = data.getvalue()
     elif filetype == "csv":
-        # attach csv
+        maintype = "text"
+        subtype = "csv"
+        payload = data.encode("utf-8")
         part = MIMEBase("text", "csv")
-        part.set_payload(data.encode("utf-8"))
-        encode_base64(part)
-    part.add_header("Content-Disposition", f"attachment; filename={basename(filename)}")
+
+    part = MIMEBase(maintype, subtype)
+    part.set_payload(payload)
+    encode_base64(part)
+    part.add_header(
+        "Content-Disposition", f"attachment; filename={Path(filename).name}"
+    )
     return part
 
 
-# reducing the arguments even more does not seem practical
-# pylint: disable-msg=too-many-arguments,invalid-name
-def create_message(
-    sender, recipient, subject, text, filename, filetype, data, cc=None, bcc=None
-):
+def create_message(  # noqa: PLR0913
+    sender: str,
+    recipient: str,
+    subject: str,
+    text: str,
+    filename: str,
+    filetype: str,
+    data: Any,  # noqa: ANN401
+    cc: str | None = None,
+    bcc: str | None = None,
+) -> MIMEMultipart:
     """Create email message.
 
     Arguments:
+    ---------
         sender: The sender of the email. Login will be made with this user.
         recipient: The recipient of the email. Can be a list.
         subject: The subject of the email.
@@ -675,6 +830,9 @@ def create_message(
         filename: The filename of the attachment
         filetype: The filetype of the attachment
         data: The attachment data.
+        cc: cc recipient
+        bcc: bcc recipient
+
     """
     msg = MIMEMultipart()
     msg["From"] = sender
@@ -692,13 +850,21 @@ def create_message(
     return msg
 
 
-def send_message(msg, server="127.0.0.1", login=None, password=None):
+def send_message(
+    msg: MIMEMultipart,
+    server: str = "127.0.0.1",
+    login: str | None = None,
+    password: str | None = None,
+) -> None:
     """Send email.
 
     Arguments:
+    ---------
         msg: The message to send (an email.messag.Message object)
         server: The SMTP server to use to send the email.
+        login: The username for `sender`@`server`.
         password: The password for `sender`@`server`.
+
     """
     with SMTP(server) as smtp:
         smtp.starttls()
@@ -710,41 +876,45 @@ def send_message(msg, server="127.0.0.1", login=None, password=None):
         smtp.send_message(msg)
 
 
-def main():  # pragma: no cover
+def main() -> None:  # pragma: no cover
     """Entrypoint for SUISA Sendemeldung ."""
-    default_config_file = basename(__file__).replace(".py", ".conf")
-    # config file in /etc gets overriden by the one in $HOME which gets overriden by the one in the
-    # current directory
+    default_config_file: str = Path(__file__).name.replace(".py", ".conf")
+    # config file in /etc gets overriden by the one in $HOME which gets overriden by the
+    # one in the current directory
     default_config_files = [
-        "/etc/" + default_config_file,
-        expanduser("~") + "/" + default_config_file,
+        str(Path("/etc") / default_config_file),
+        str(Path("~").expanduser() / default_config_file),
         default_config_file,
     ]
     parser = ArgumentParser(
         default_config_files=default_config_files,
         description="ACRCloud client for SUISA reporting @ RaBe.",
     )
-    args = get_arguments(parser)
+    args = get_arguments(parser, sys.argv[1:])
 
     start_date, end_date = parse_date(args)
     filename = parse_filename(args, start_date)
 
     client = ACRClient(bearer_token=args.bearer_token)
     data = client.get_interval_data(
-        args.project_id, args.stream_id, start_date, end_date, timezone=args.timezone
+        args.project_id,
+        args.stream_id,
+        start_date,
+        end_date,
+        timezone=args.timezone,
     )
     data = merge_duplicates(data)
     if args.filetype == "xlsx":
-        data = get_xlsx(data, station_name=args.station_name)
+        data = get_xlsx(data, args=args)
     elif args.filetype == "csv":
-        data = get_csv(data, station_name=args.station_name)
+        data = get_csv(data, args=args)
     if args.email:
         email_subject = Template(args.email_subject).substitute(
             {
                 "station_name": args.station_name,
                 "year": format_date(start_date, format="yyyy", locale=args.locale),
                 "month": format_date(start_date, format="MM", locale=args.locale),
-            }
+            },
         )
         # generate body
         text = Template(args.email_text).substitute(
@@ -753,16 +923,18 @@ def main():  # pragma: no cover
                 "month": format_date(start_date, format="MMMM", locale=args.locale),
                 "year": format_date(start_date, format="yyyy", locale=args.locale),
                 "previous_year": format_date(
-                    start_date - timedelta(days=365), format="yyyy", locale=args.locale
+                    start_date - timedelta(days=365),
+                    format="yyyy",
+                    locale=args.locale,
                 ),
                 "in_three_months": format_date(
-                    datetime.now() + relativedelta(months=+3),
+                    datetime.now() + relativedelta(months=+3),  # noqa: DTZ005
                     format="long",
                     locale=args.locale,
                 ),
                 "responsible_email": args.responsible_email,
                 "email_footer": args.email_footer,
-            }
+            },
         )
         msg = create_message(
             args.email_from,
@@ -786,7 +958,7 @@ def main():  # pragma: no cover
     elif args.file and args.filetype == "csv":
         write_csv(filename, data)
     if args.stdout and args.filetype == "csv":
-        print(data)
+        print(data)  # noqa: T201
 
 
 if __name__ == "__main__":  # pragma: no cover
